# Grakn Client RPC (Remote Procedure Call) Protocol

A protocol for implementing a Grakn client driver, in many popular programming languages, using [GRPC (Google's Remote Procedure Call)](https://grpc.io) framework.
